[![kinisi Logo](https://github.com/bjmorgan/kinisi/raw/master/docs/source/_static/kinisi_logo.png)](https://kinisi.readthedocs.io)

Pronunciation: *kee-nee-si*

[![Test Coverage](https://api.codeclimate.com/v1/badges/3e64239fb6cb6c837b62/test_coverage)](https://codeclimate.com/github/bjmorgan/kinisi/test_coverage)
[![Documentation Status](https://readthedocs.org/projects/kinisi/badge/?version=latest)](https://kinisi.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/kinisi.svg)](https://badge.fury.io/py/kinisi)

`kinisi` is an open-source package focussed on accurately quantifying the uncertainty in atomic and molecular displacements, and using this to more completely understand diffusion in materials.

## Installation

`kinisi` is available from the [PyPI](https://pypi.org/project/kinisi/) repository so can be installed using `pip` or alternatively `clone` [this repository](https://github.com/bjmorgan/kinisi) and install the latest development build with the commands below.

```
pip install -r requirements.txt
pip install .
pytest
```
